PyXMake Developer Guide: PyXMake.VTL.stm_make.sphinx_stmlab Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.sphinx_stmlab Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.sphinx_stmlab:

## Public Attributes
list | include_path
| logo = os.path.join(__pyc_core_path,"VTL","doc","mcd_stmlab","pics","stm_lab_logo_bubbles.png")
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_sphinx
int | verbose = 0
str | include_path = ""
str | source_path = ''
str | output_file_path = ''
| scratch_path = os.getcwd()
| logo = None
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_sphinx
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
str | _BUILD_NAME = 'Structural Mechanics Lab'
str | _INPUT_FILE = "stm_lab"
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_sphinx
str | _BUILD_NAME = ''
str | _INPUT_FILE = ""

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_sphinx
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_sphinx
str | description = "Runs the html documentation build process of source code using Sphinx."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs the html documentation build process for Structural Mechanics Lab using a scheme from ReadtheDocs.

Definition at line 340 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.sphinx_stmlab._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 348 of file stm_make.py.

## Member Data Documentation

## ◆ _BUILD_NAME

str PyXMake.VTL.stm_make.sphinx_stmlab._BUILD_NAME = 'Structural Mechanics Lab'
| staticprotected

Definition at line 345 of file stm_make.py.

## ◆ _INPUT_FILE

str PyXMake.VTL.stm_make.sphinx_stmlab._INPUT_FILE = "stm_lab"
| staticprotected

Definition at line 346 of file stm_make.py.

## ◆ include_path

list PyXMake.VTL.stm_make.sphinx_stmlab.include_path

Initial value:
= [os.path.join(__pyc_core_path,"Plugin","Smetana"),
os.path.join(__pyc_core_path,"Plugin","Smetana","src","Smetana"),
os.path.join(__pyc_core_path,"Core","bin",__platform,__arch)]

Definition at line 358 of file stm_make.py.

## ◆ logo

PyXMake.VTL.stm_make.sphinx_stmlab.logo = os.path.join(__pyc_core_path,"VTL","doc","mcd_stmlab","pics","stm_lab_logo_bubbles.png")

Definition at line 361 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py